/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.chart;

import java.util.HashMap;
import java.util.Map;

import org.junit.Assert;
import org.junit.Test;
import org.xwiki.chart.internal.DefaultChartGenerator;
import org.xwiki.chart.model.ChartModel;
import org.xwiki.chart.model.DefaultChartModel;
import org.xwiki.test.AbstractComponentTestCase;

/**
 * Test case for {@link DefaultChartGenerator}.
 * 
 * @version $Id: f895b78ddf23a6cb178df7b2cc09a5b2648ecedd $
 * @since 2.0M1
 */
public class DefaultChartGeneratorTest extends AbstractComponentTestCase
{
    /**
     * The {@link ChartGenerator} component.
     */
    private ChartGenerator chartGenerator;

    /**
     * The {@link ChartModel}.
     */
    private ChartModel model;

    @Override
    protected void registerComponents() throws Exception
    {
        Short dataArray[][] = { {1, 2, 3}, {1, 3, 5}};
        String rowHeaders[] = {"1", "2"};
        String columnHeaders[] = {"1", "2", "3"};
        this.model = new DefaultChartModel(dataArray, rowHeaders, columnHeaders);
        this.chartGenerator = getComponentManager().lookup(ChartGenerator.class);
    }

    /**
     * Test pie chart generation.
     * 
     * @throws ChartGeneratorException if an error occurs while generating the chart.
     */
    @Test
    public final void testPieChart() throws ChartGeneratorException
    {
        Map<String, String> parameters = new HashMap<String, String>();
        parameters.put(ChartGenerator.TITLE_PARAM, "Test pie chart");
        parameters.put(ChartGenerator.TYPE_PARAM, "pie");
        parameters.put(ChartGenerator.SERIES_PARAM, "rows");

        byte[] chart = chartGenerator.generate(model, parameters);
        Assert.assertNotNull(chart);
    }

    /**
     * Test bar chart generation.
     * 
     * @throws ChartGeneratorException if an error occurs while generating the chart.
     */
    @Test
    public final void testBarChart() throws ChartGeneratorException
    {
        Map<String, String> parameters = new HashMap<String, String>();
        parameters.put(ChartGenerator.TITLE_PARAM, "Test bar chart");
        parameters.put(ChartGenerator.TYPE_PARAM, "bar");
        parameters.put(ChartGenerator.SERIES_PARAM, "rows");

        byte[] chart = chartGenerator.generate(model, parameters);
        Assert.assertNotNull(chart);
    }

    /**
     * Test line chart generation.
     * 
     * @throws ChartGeneratorException if an error occurs while generating the chart.
     */
    @Test
    public final void testLineChart() throws ChartGeneratorException
    {
        Map<String, String> parameters = new HashMap<String, String>();
        parameters.put(ChartGenerator.TITLE_PARAM, "Test line chart");
        parameters.put(ChartGenerator.TYPE_PARAM, "line");
        parameters.put(ChartGenerator.SERIES_PARAM, "rows");

        byte[] chart = chartGenerator.generate(model, parameters);
        Assert.assertNotNull(chart);
    }

    /**
     * Test area chart generation.
     * 
     * @throws ChartGeneratorException if an error occurs while generating the chart.
     */
    @Test
    public final void testAreaChart() throws ChartGeneratorException
    {
        Map<String, String> parameters = new HashMap<String, String>();
        parameters.put(ChartGenerator.TITLE_PARAM, "Test area chart");
        parameters.put(ChartGenerator.TYPE_PARAM, "area");
        parameters.put(ChartGenerator.SERIES_PARAM, "rows");

        byte[] chart = chartGenerator.generate(model, parameters);
        Assert.assertNotNull(chart);
    }
}
